changeset 136:c445cdf36fb1

Fix new naming convention for the generation of the problem from .ufl file.
author gedeone-octave <marcovass89@hotmail.it>
date Fri, 06 Sep 2013 13:42:20 +0200
parents 547763139e1a
children 3a0f952a79ec
files inst/fem_create_fs.m inst/fem_create_functional.m inst/import_ufl_BilinearForm.m inst/import_ufl_FunctionSpace.m inst/import_ufl_Functional.m inst/import_ufl_LinearForm.m inst/import_ufl_Problem.m inst/import_ufl_problem.m
diffstat 8 files changed, 174 insertions(+), 189 deletions(-) [+]
line wrap: on
line diff
--- a/inst/fem_create_fs.m	Fri Sep 06 13:30:10 2013 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,56 +0,0 @@
-## Copyright (C) 2013 Marco Vassallo
-
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 2 of the License, or (at your option) any later
-## version.
-
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
-
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
-
-
-## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
-## @end deftypefn
-
-function fem_create_fs (var_prob)
-
-  if nargin != 1
-    error ("fem_create_fs: wrong number of input parameters.");
-  elseif ! ischar (var_prob)
-    error ("fem_create_fs: first argument is not a valid string");
-  endif
-
-  n = length (mfilename ("fullpath")) - length (mfilename());
-  path = strtrunc(mfilename ("fullpath"), n);
-
-  private = fullfile (path, "private/");
-  output = generate_fs (var_prob);
-  output += generate_makefile (var_prob, private);
-  if output != 0
-    error ("Compilation failed");
-  else
-    [output, textfile] = system (sprintf ("make -f Makefile_%s fs", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-  endif
-
-endfunction
--- a/inst/fem_create_functional.m	Fri Sep 06 13:30:10 2013 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,55 +0,0 @@
-## Copyright (C) 2013 Marco Vassallo
-
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 2 of the License, or (at your option) any later
-## version.
-
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
-
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
-
-
-## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
-## @end deftypefn
-
-function fem_create_functional (var_prob)
-
-  if nargin != 1
-    error ("fem_create_functional: wrong number of input parameters.");
-  elseif ! ischar (var_prob)
-    error ("fem_create_functional: first argument is not a valid string");
-  endif
-
-  n = length (mfilename ("fullpath")) - length (mfilename());
-  path = strtrunc(mfilename ("fullpath"), n);
-
-  private = fullfile (path, "private/");
-  output = generate_fun (var_prob);
-  output += generate_makefile (var_prob, private);
-  if output != 0
-    error ("Compilation failed");
-  else
-    [output, textfile] = system (sprintf ("make -f Makefile_%s fun", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-  endif
-endfunction
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/inst/import_ufl_FunctionSpace.m	Fri Sep 06 13:42:20 2013 +0200
@@ -0,0 +1,53 @@
+## Copyright (C) 2013 Marco Vassallo
+
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 2 of the License, or (at your option) any later
+## version.
+
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
+
+
+## -*- texinfo -*-
+## @deftypefn {Function File} {} = import_ufl_FunctionSpace (myproblem)
+## This function takes as input the name of the .ufl file where 
+## the FunctionSpace is defined and import it inside Octave
+## @seealso{import_ufl_Problem, FunctionSpace, BilinearForm, LinearForm} 
+## @end deftypefn
+
+function import_ufl_FunctionSpace (var_prob)
+
+  if nargin != 1
+    error ("import_ufl_FunctionSpace: wrong number of input parameters.");
+  elseif ! ischar (var_prob)
+    error ("import_ufl_FunctionSpace: first argument is not a valid string");
+  endif
+
+  n = length (mfilename ("fullpath")) - length (mfilename());
+  path = strtrunc(mfilename ("fullpath"), n);
+
+  private = fullfile (path, "private/");
+  output = generate_fs (var_prob);
+  output += generate_makefile (var_prob, private);
+  if output != 0
+    error ("Compilation failed");
+  else
+    [output, textfile] = system (sprintf ("make -f Makefile_%s fs", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+  endif
+
+endfunction
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/inst/import_ufl_Functional.m	Fri Sep 06 13:42:20 2013 +0200
@@ -0,0 +1,51 @@
+## Copyright (C) 2013 Marco Vassallo
+
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 2 of the License, or (at your option) any later
+## version.
+
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
+
+## -*- texinfo -*-
+## @deftypefn {Function File} {} = import_ufl_Functional (myproblem)
+## This function takes as input the name of the .ufl file where 
+## the Functional is defined and import it inside Octavet.
+## @seealso{import_ufl_Problem, FunctionSpace, BilinearForm, LinearForm} 
+## @end deftypefn
+
+function import_ufl_Functional (var_prob)
+
+  if nargin != 1
+    error ("import_ufl_Functional: wrong number of input parameters.");
+  elseif ! ischar (var_prob)
+    error ("import_ufl_Functional: first argument is not a valid string");
+  endif
+
+  n = length (mfilename ("fullpath")) - length (mfilename());
+  path = strtrunc(mfilename ("fullpath"), n);
+
+  private = fullfile (path, "private/");
+  output = generate_fun (var_prob);
+  output += generate_makefile (var_prob, private);
+  if output != 0
+    error ("Compilation failed");
+  else
+    [output, textfile] = system (sprintf ("make -f Makefile_%s fun", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+  endif
+endfunction
--- /dev/null	Thu Jan 01 00:00:00 1970 +0000
+++ b/inst/import_ufl_Problem.m	Fri Sep 06 13:42:20 2013 +0200
@@ -0,0 +1,56 @@
+## Copyright (C) 2013 Marco Vassallo
+
+## This program is free software; you can redistribute it and/or modify it under
+## the terms of the GNU General Public License as published by the Free Software
+## Foundation; either version 2 of the License, or (at your option) any later
+## version.
+
+## This program is distributed in the hope that it will be useful, but WITHOUT
+## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
+## details.
+
+## You should have received a copy of the GNU General Public License along with
+## this program; if not, see <http://www.gnu.org/licenses/>.
+
+
+## -*- texinfo -*-
+## @deftypefn {Function File} {} = import_ufl_Problem (myproblem)
+## This function take as input the name of the .ufl file where 
+## the Variational Problem is defined and import it inside Octave.
+## It expect that a ilinearForm and a LinearForm are defined inside the .ufl file.
+## @seealso{FunctionSpace, BilinearForm, LinearForm} 
+## @end deftypefn
+
+function import_ufl_Problem (var_prob)
+
+  if nargin != 1
+    error ("import_ufl_Problem: wrong number of input parameters.");
+  elseif ! ischar (var_prob)
+    error ("import_ufl_Problem: first argument is not a valid string");
+  endif
+
+  n = length (mfilename ("fullpath")) - length (mfilename());
+  path = strtrunc(mfilename ("fullpath"), n);
+
+  private = fullfile (path, "private/");
+  output = generate_fs (var_prob);
+  output += generate_rhs (var_prob);
+  output += generate_lhs (var_prob);
+  output += generate_makefile (var_prob, private);
+  if output != 0
+    error ("Compilation failed");
+  else
+    [output, textfile] = system (sprintf ("make -f Makefile_%s all", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
+    if output != 0
+      display (text);
+      error ("Compilation failed");
+    endif
+  endif
+
+endfunction
--- a/inst/import_ufl_problem.m	Fri Sep 06 13:30:10 2013 +0200
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,58 +0,0 @@
-## Copyright (C) 2013 Marco Vassallo
-
-## This program is free software; you can redistribute it and/or modify it under
-## the terms of the GNU General Public License as published by the Free Software
-## Foundation; either version 2 of the License, or (at your option) any later
-## version.
-
-## This program is distributed in the hope that it will be useful, but WITHOUT
-## ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-## FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
-## details.
-
-## You should have received a copy of the GNU General Public License along with
-## this program; if not, see <http://www.gnu.org/licenses/>.
-
-
-## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
-## @end deftypefn
-
-function fem_create_all (var_prob)
-
-  if nargin != 1
-    error ("fem_create_fs: wrong number of input parameters.");
-  elseif ! ischar (var_prob)
-    error ("fem_create_fs: first argument is not a valid string");
-  endif
-
-  n = length (mfilename ("fullpath")) - length (mfilename());
-  path = strtrunc(mfilename ("fullpath"), n);
-
-  private = fullfile (path, "private/");
-  output = generate_fs (var_prob);
-  output += generate_rhs (var_prob);
-  output += generate_lhs (var_prob);
-  output += generate_makefile (var_prob, private);
-  if output != 0
-    error ("Compilation failed");
-  else
-    [output, textfile] = system (sprintf ("make -f Makefile_%s all", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-    [output, textfile] = system (sprintf ("make -f Makefile_%s clean", var_prob));
-    if output != 0
-      display (text);
-      error ("Compilation failed");
-    endif
-  endif
-
-endfunction
--- a/inst/import_ufl_BilinearForm.m	Fri Sep 06 13:30:10 2013 +0200
+++ b/inst/import_ufl_BilinearForm.m	Fri Sep 06 13:42:20 2013 +0200
@@ -15,21 +15,18 @@
 
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
 ## This function take as input the name of the .ufl file where 
 ## the Variational Problem is defined.
 ## @example
 ## 
 ## @end example
 ## @seealso{} 
 ## @end deftypefn
 
-function fem_create_rhs (var_prob)
+function import_ufl_BilinearForm (var_prob)
 
   if nargin != 1
-    error ("fem_create_rhs: wrong number of input parameters.");
+    error ("import_ufl_BilinearForm: wrong number of input parameters.");
   elseif ! ischar (var_prob)
-    error ("fem_create_rhs: first argument is not a valid string");
+    error ("import_ufl_BilinearForm: first argument is not a valid string");
   endif
 
   n = length (mfilename ("fullpath")) - length (mfilename());
@@ -15,21 +15,18 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
+## @deftypefn {Function File} {} = import_ufl_BilinearForm (myproblem)
+## This function takes as input the name of the .ufl file where 
+## the BilinearForm is defined and import it inside Octave.
+## @seealso{import_ufl_Problem, FunctionSpace, BilinearForm, LinearForm} 
 ## @end deftypefn
 
--- a/inst/import_ufl_LinearForm.m	Fri Sep 06 13:30:10 2013 +0200
+++ b/inst/import_ufl_LinearForm.m	Fri Sep 06 13:42:20 2013 +0200
@@ -15,21 +15,18 @@
 
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
 ## This function take as input the name of the .ufl file where 
 ## the Variational Problem is defined.
 ## @example
 ## 
 ## @end example
 ## @seealso{} 
 ## @end deftypefn
 
-function fem_create_lhs (var_prob)
+function import_ufl_LinearForm (var_prob)
 
   if nargin != 1
-    error ("fem_create_lhs: wrong number of input parameters.");
+    error ("import_ufl_LinearForm: wrong number of input parameters.");
   elseif ! ischar (var_prob)
-    error ("fem_create_lhs: first argument is not a valid string");
+    error ("import_ufl_LinearForm: first argument is not a valid string");
   endif
 
   n = length (mfilename ("fullpath")) - length (mfilename());
@@ -15,21 +15,18 @@
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} = fem_ffc (myproblem.ufl)
-## This function take as input the name of the .ufl file where 
-## the Variational Problem is defined.
-## @example
-## 
-## @end example
-## @seealso{} 
+## @deftypefn {Function File} {} = import_ufl_LinearForm (myproblem)
+## This function takes as input the name of the .ufl file where 
+## the LinearForm is defined and import it inside Octave
+## @seealso{import_ufl_Problem, FunctionSpace, BilinearForm, LinearForm} 
 ## @end deftypefn
 